import os
from setuptools import setup, find_packages

here = os.path.abspath(os.path.dirname(__file__))

about = {}
with open(os.path.join(here, "sketchingdev", "__about__.py")) as f:
    exec(f.read(), about)

setup(
    name=about['__name__'],
    version=about['__version__'],
    description="Console display for Doodle-Dashboard.",
    url="https://github.com/SketchingDev/Doodle-Dashboard-Display",
    license="MIT",
    packages=["sketchingdev"],
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Programming Language :: Python :: 3.4"
    ],
    python_requires=">=3.4"
)



from abc import ABC, abstractmethod


class CanWriteText(ABC):
    """Mixin that indicates the display can write text"""

    @abstractmethod
    def write_text(self, text):
        pass


class CanDrawImage(ABC):
    """Mixin that indicates the display can draw an image"""

    @abstractmethod
    def draw_image(self, path):
        pass


class CanColourFill(ABC):
    """Mixin that indicates the display can be filled with colour"""

    @abstractmethod
    def fill_colour(self, colour):
        pass


class Display(ABC):
    """Base class that every display must implement"""
    @abstractmethod
    def clear(self):
        pass

    @staticmethod
    @abstractmethod
    def get_id():
        pass
